use Perlmazing qw(_isa_ref);

sub main ($) {
	_isa_ref('IO', $_[0]);
}

